@@ -13,7 +13,7 @@ t.add_description(
     "AWS CloudFormation Sample Template CloudFront_S3: Sample template "
     "showing how to create an Amazon CloudFront distribution using an "
     "S3 origin. "
-    "**WARNING** This template creates an Amazon EC2 instance. "
+    "**WARNING** This template creates a CloudFront distribution. "
     "You will be billed for the AWS resources used if you create "
     "a stack from this template.")
 
