@@ -2,10 +2,10 @@
 # http://aws.amazon.com/cloudformation/aws-cloudformation-templates/
 
 from troposphere import Output, Parameter, Ref, Template
-from troposphere.dynamodb import Element, PrimaryKey, ProvisionedThroughput
+from troposphere.dynamodb import (Key, AttributeDefinition,
+                                  ProvisionedThroughput)
 from troposphere.dynamodb import Table
 
-
 t = Template()
 
 t.add_description("AWS CloudFormation Sample Template: This template "
@@ -54,10 +54,16 @@ writeunits = t.add_parameter(Parameter(
 
 myDynamoDB = t.add_resource(Table(
     "myDynamoDBTable",
-    KeySchema=PrimaryKey(
-        HashKeyElement=Element(Ref(hashkeyname), Ref(hashkeytype))),
+    AttributeDefinitions=[
+        AttributeDefinition(Ref(hashkeyname), Ref(hashkeytype)),
+    ],
+    KeySchema=[
+        Key(Ref(hashkeyname), "HASH")
+    ],
     ProvisionedThroughput=ProvisionedThroughput(
-        Ref(readunits), Ref(writeunits)),
+        Ref(readunits),
+        Ref(writeunits)
+    )
 ))
 
 t.add_output(Output(
