@@ -1,8 +1,7 @@
 # Converted from S3_Bucket.template located at:
 # http://aws.amazon.com/cloudformation/aws-cloudformation-templates/
 
-from troposphere import FindInMap, GetAtt, Join, Output
-from troposphere import Parameter, Ref, Template
+from troposphere import Output, Ref, Template
 from troposphere.s3 import Bucket, PublicRead
 
 
@@ -15,13 +14,12 @@ t.add_description(
     "You will be billed for the AWS resources used if you create "
     "a stack from this template.")
 
-s3bucket = t.add_resource(Bucket("S3Bucket",
-    AccessControl=PublicRead,
-))
+s3bucket = t.add_resource(Bucket("S3Bucket", AccessControl=PublicRead,))
 
-t.add_output(Output("BucketName",
+t.add_output(Output(
+    "BucketName",
     Value=Ref(s3bucket),
     Description="Name of S3 bucket to hold website content"
 ))
 
-print t.to_json()
+print(t.to_json())
