@@ -35,7 +35,9 @@ class OptionSettings(AWSProperty):
     }
 
 
-class ConfigurationTemplate(AWSProperty):
+class ConfigurationTemplate(AWSObject):
+    resource_type = "AWS::ElasticBeanstalk::ConfigurationTemplate"
+
     props = {
         'TemplateName': (basestring, True),
         'Description': (basestring, False),
@@ -45,7 +47,7 @@ class ConfigurationTemplate(AWSProperty):
 
 
 class Application(AWSObject):
-    type = "AWS::ElasticBeanstalk::Application"
+    resource_type = "AWS::ElasticBeanstalk::Application"
 
     props = {
         'ApplicationName': (basestring, False),
@@ -78,7 +80,7 @@ class Tier(AWSProperty):
 
 
 class Environment(AWSObject):
-    type = "AWS::ElasticBeanstalk::Environment"
+    resource_type = "AWS::ElasticBeanstalk::Environment"
 
     props = {
         'ApplicationName': (basestring, True),
